@@ -1,6 +1,6 @@
 package Chloro::Error::Field;
 BEGIN {
-  $Chloro::Error::Field::VERSION = '0.04';
+  $Chloro::Error::Field::VERSION = '0.05';
 }
 
 use Moose;
@@ -9,7 +9,6 @@ use MooseX::StrictConstructor;
 use namespace::autoclean;
 
 use Chloro::Field;
-use Chloro::Types qw( NonEmptyStr );
 
 with 'Chloro::Role::Error';
 
@@ -19,6 +18,13 @@ has field => (
     required => 1,
 );
 
+has result => (
+    is       => 'rw',
+    writer   => '_set_result',
+    isa      => 'Chloro::Result::Field',
+    weak_ref => 1,
+);
+
 has message => (
     is       => 'ro',
     isa      => 'Chloro::ErrorMessage',
@@ -41,7 +47,7 @@ Chloro::Error::Field - An error associated with a specific field
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -65,6 +71,11 @@ This class has the following methods:
 
 Returns the L<Chloro::Field> object associated with this error.
 
+=head2 $error->result()
+
+Returns the L<Chloro::Result::Field> object associated with this error. This
+is a weak reference, so it could return C<undef>.
+
 =head2 $error->message()
 
 Returns a L<Chloro::ErrorMessage> object.
