@@ -1,6 +1,6 @@
 package Chloro::Result::Field;
 BEGIN {
-  $Chloro::Result::Field::VERSION = '0.04';
+  $Chloro::Result::Field::VERSION = '0.05';
 }
 
 use Moose;
@@ -8,7 +8,7 @@ use MooseX::StrictConstructor;
 
 use namespace::autoclean;
 
-use Chloro::Types qw( ArrayRef Item );
+use Chloro::Types qw( ArrayRef Item NonEmptyStr );
 
 with 'Chloro::Role::Result';
 
@@ -18,11 +18,18 @@ has _errors => (
     init_arg => 'errors',
     required => 1,
     handles  => {
-        errors   => 'elements',
-        is_valid => 'is_empty',
+        errors    => 'elements',
+        is_valid  => 'is_empty',
+        add_error => 'push',
     },
 );
 
+has param_names => (
+    is       => 'ro',
+    isa      => ArrayRef[NonEmptyStr],
+    required => 1,
+);
+
 has field => (
     is       => 'ro',
     isa      => 'Chloro::Field',
@@ -35,6 +42,21 @@ has value => (
     predicate => 'has_value',
 );
 
+sub BUILD {
+    my $self = shift;
+
+    $_->_set_result($self) for $self->errors();
+
+    return;
+}
+
+after add_error => sub {
+    my $self = shift;
+    my $error = shift;
+
+    $error->_set_result($self);
+};
+
 sub key_value_pairs {
     my $self = shift;
 
@@ -59,7 +81,7 @@ Chloro::Result::Field - A result for a single field
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -109,6 +131,13 @@ Returns true if there are no errors associated with this result.
 
 Returns the L<Chloro::Field> object for this result.
 
+=head2 $result->param_names()
+
+Returns an array reference of the parameter keys associated with this
+field. The names are returned by the extractor method. For most fields, this
+will always be a one value arrayref, but it could be empty or have multiple
+names with a custom extractor.
+
 =head2 $result->value()
 
 Returns the value for this field. This can be any data type, undef,
