@@ -1,6 +1,6 @@
 package Chloro::Role::Trait::HasFormComponents;
 BEGIN {
-  $Chloro::Role::Trait::HasFormComponents::VERSION = '0.04';
+  $Chloro::Role::Trait::HasFormComponents::VERSION = '0.05';
 }
 
 use Moose::Role;
@@ -16,7 +16,8 @@ has _fields => (
     default  => sub { Tie::IxHash->new() },
     handles  => {
         _add_field   => 'STORE',
-        _has_field   => 'EXISTS',
+        has_field    => 'EXISTS',
+        get_field    => 'FETCH',
         local_fields => 'Values',
     },
 );
@@ -27,7 +28,7 @@ has _groups => (
     default  => sub { Tie::IxHash->new() },
     handles  => {
         _add_group   => 'STORE',
-        _has_group   => 'EXISTS',
+        has_group   => 'EXISTS',
         local_groups => 'Values',
     },
 );
@@ -36,12 +37,12 @@ sub add_field {
     my $self  = shift;
     my $field = shift;
 
-    if ( $self->_has_field( $field->name() ) ) {
+    if ( $self->has_field( $field->name() ) ) {
         my $name = $field->name();
         croak "Cannot add two fields with the same name ($name)";
     }
 
-    if ( $self->_has_group( $field->name() ) ) {
+    if ( $self->has_group( $field->name() ) ) {
         my $name = $field->name();
         croak "Cannot share a name between a field and a group ($name)";
     }
@@ -55,12 +56,12 @@ sub add_group {
     my $self  = shift;
     my $group = shift;
 
-    if ( $self->_has_group( $group->name() ) ) {
+    if ( $self->has_group( $group->name() ) ) {
         my $name = $group->name();
         croak "Cannot add two groups with the same name ($name)";
     }
 
-    if ( $self->_has_field( $group->name() ) ) {
+    if ( $self->has_field( $group->name() ) ) {
         my $name = $group->name();
         croak "Cannot share a name between a field and a group ($name)";
     }
@@ -93,7 +94,7 @@ Chloro::Role::Trait::HasFormComponents - A metaclass trait for classes and roles
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
